@@ -189,7 +189,7 @@ setMethod("colMaxs", signature(x = "dgCMatrix"),
 #'
 #' @export
 setMethod("colOrderStats", signature(x = "dgCMatrix"),
-          function(x, rows = NULL, cols = NULL, which = 1, useNames = NA, na.rm=FALSE){
+          function(x, rows = NULL, cols = NULL, which = 1, na.rm=FALSE, ..., useNames = NA){
   if(which < 1 || which > nrow(x)){
     stop("Argument 'which' is out of range.")
   }
